@@ -3,7 +3,6 @@ package main
 
 import (
 	"bytes"
-	"crypto/tls"
 	"encoding/json"
 	"errors"
 	"fmt"
@@ -70,7 +69,7 @@ func init() {
 		`.restore FILE                                 Load using SQLite file or SQL dump contained in FILE`,
 		`.nodes [all]                                  Show connection status of voting nodes. 'all' to show all nodes`,
 		`.schema                                       Show CREATE statements for all tables`,
-		`.snapshot                                     Request a Raft snapshot and log trunction on connected node`,
+		`.snapshot                                     Request a Raft snapshot and log truncation on connected node`,
 		`.status                                       Show status and diagnostic information for connected node`,
 		`.sysdump FILE                                 Dump system diagnostics to FILE`,
 		`.tables                                       List names of tables`,
@@ -175,7 +174,7 @@ func main() {
 				}
 				err = setConsistency(line[index+1:], &consistency)
 			case ".EXTENSIONS":
-				err = extensions(ctx, cmd, argv)
+				err = extensions(ctx, client, cmd, argv)
 			case ".TABLES":
 				err = queryWithClient(ctx, client, timer, blobArray, consistency, `SELECT name FROM sqlite_master WHERE type="table"`)
 			case ".INDEXES":
@@ -187,19 +186,19 @@ func main() {
 			case ".BLOBARRAY":
 				err = toggleFlag(line[index+1:], &blobArray)
 			case ".STATUS":
-				err = status(ctx, cmd, line, argv)
+				err = status(ctx, client, cmd, argv)
 			case ".READY":
-				err = ready(ctx, httpClient, argv)
+				err = ready(ctx, client, argv)
 			case ".NODES":
 				if index == -1 || index == len(line)-1 {
-					err = nodes(ctx, cmd, line, argv, false)
+					err = nodes(ctx, client, cmd, line, argv, false)
 					break
 				}
-				err = nodes(ctx, cmd, line, argv, true)
+				err = nodes(ctx, client, cmd, line, argv, true)
 			case ".EXPVAR":
-				err = expvar(ctx, cmd, line, argv)
+				err = expvar(ctx, client, cmd, line, argv)
 			case ".REMOVE":
-				err = removeNode(httpClient, line[index+1:], argv, timer)
+				err = removeNode(client, line[index+1:], argv)
 			case ".BACKUP":
 				if index == -1 || index == len(line)-1 {
 					err = fmt.Errorf("please specify an output file for the backup")
@@ -231,7 +230,7 @@ func main() {
 				}
 				err = dump(ctx, line[index+1:], argv)
 			case ".HELP":
-				err = help(ctx, cmd, line, argv)
+				ctx.String("%s", strings.Join(cliHelp, "\n"))
 			case ".QUIT", "QUIT", "EXIT", ".EXIT":
 				break FOR_READ
 			case ".SNAPSHOT":
@@ -241,14 +240,14 @@ func main() {
 			default:
 				err = executeWithClient(ctx, client, timer, line)
 			}
-			if err != nil {
-				// if a previous request was executed on a different host, make that change
+			if hcerr, ok := err.(*httpcl.HostChangedError); ok {
+				// If a previous request was executed on a different host, make that change
 				// visible to the user.
-				if hcerr, ok := err.(*httpcl.HostChangedError); ok {
+				if hcerr != nil {
 					prefix = fmt.Sprintf("%s>", hcerr.NewHost)
-				} else {
-					ctx.String("%s %v\n", ctx.Color().Red("ERR!"), err)
 				}
+			} else if err != nil {
+				ctx.String("%s %v\n", ctx.Color().Red("ERR!"), err)
 			}
 		}
 
@@ -290,17 +289,12 @@ func makeJSONBody(line string) string {
 	return string(data)
 }
 
-func help(ctx *cli.Context, cmd, line string, argv *argT) error {
-	fmt.Println(strings.Join(cliHelp, "\n"))
-	return nil
-}
-
-func status(ctx *cli.Context, cmd, line string, argv *argT) error {
+func status(ctx *cli.Context, client *httpcl.Client, line string, argv *argT) error {
 	url := fmt.Sprintf("%s://%s/status", argv.Protocol, address6(argv))
-	return cliJSON(ctx, cmd, line, url, argv)
+	return cliJSON(ctx, client, line, url)
 }
 
-func ready(ctx *cli.Context, client *http.Client, argv *argT) error {
+func ready(ctx *cli.Context, client *httpcl.Client, argv *argT) error {
 	u := url.URL{
 		Scheme: argv.Protocol,
 		Host:   address6(argv),
@@ -308,19 +302,7 @@ func ready(ctx *cli.Context, client *http.Client, argv *argT) error {
 	}
 	urlStr := u.String()
 
-	req, err := http.NewRequest("GET", urlStr, nil)
-	if err != nil {
-		return err
-	}
-	if argv.Credentials != "" {
-		creds := strings.Split(argv.Credentials, ":")
-		if len(creds) != 2 {
-			return fmt.Errorf("invalid Basic Auth credentials format")
-		}
-		req.SetBasicAuth(creds[0], creds[1])
-	}
-
-	resp, err := client.Do(req)
+	resp, err := client.Get(urlStr)
 	if err != nil {
 		return err
 	}
@@ -335,18 +317,18 @@ func ready(ctx *cli.Context, client *http.Client, argv *argT) error {
 
 // nodes returns the status of nodes in the cluster. If all is true, then
 // non-voting nodes are included in the response.
-func nodes(ctx *cli.Context, cmd, line string, argv *argT, all bool) error {
+func nodes(ctx *cli.Context, client *httpcl.Client, cmd, line string, argv *argT, all bool) error {
 	path := "nodes"
 	if all {
 		path = "nodes?nonvoters"
 	}
 	url := fmt.Sprintf("%s://%s/%s", argv.Protocol, address6(argv), path)
-	return cliJSON(ctx, cmd, "", url, argv)
+	return cliJSON(ctx, client, "", url)
 }
 
-func expvar(ctx *cli.Context, cmd, line string, argv *argT) error {
+func expvar(ctx *cli.Context, client *httpcl.Client, cmd, line string, argv *argT) error {
 	url := fmt.Sprintf("%s://%s/debug/vars", argv.Protocol, address6(argv))
-	return cliJSON(ctx, cmd, line, url, argv)
+	return cliJSON(ctx, client, line, url)
 }
 
 func snapshot(client *httpcl.Client, argv *argT) error {
@@ -375,6 +357,7 @@ func snapshot(client *httpcl.Client, argv *argT) error {
 }
 
 func sysdump(ctx *cli.Context, client *http.Client, filename string, argv *argT) error {
+	_ = ctx
 	nodes, err := getNodes(client, argv)
 	if err != nil {
 		return err
@@ -509,6 +492,7 @@ func sendRequest(ctx *cli.Context, makeNewRequest func(string) (*http.Request, e
 }
 
 func sendRequestW(ctx *cli.Context, makeNewRequest func(string) (*http.Request, error), urlStr string, argv *argT, w io.Writer) (int64, error) {
+	_ = ctx
 	url := urlStr
 	tlsConfig, err := rtls.CreateClientConfig(argv.ClientCert, argv.ClientKey, argv.CACert, rtls.NoServerName, argv.Insecure)
 	if err != nil {
@@ -578,25 +562,10 @@ func parseResponse(response *[]byte, ret interface{}) error {
 	return decoder.Decode(ret)
 }
 
-func extensions(ctx *cli.Context, cmd string, argv *argT) error {
-	client := http.Client{Transport: &http.Transport{
-		TLSClientConfig: &tls.Config{InsecureSkipVerify: argv.Insecure},
-		Proxy:           http.ProxyFromEnvironment,
-	}}
-
-	req, err := http.NewRequest("GET", fmt.Sprintf("%s://%s/status?key=extensions", argv.Protocol, address6(argv)), nil)
-	if err != nil {
-		return err
-	}
-	if argv.Credentials != "" {
-		creds := strings.Split(argv.Credentials, ":")
-		if len(creds) != 2 {
-			return fmt.Errorf("invalid Basic Auth credentials format")
-		}
-		req.SetBasicAuth(creds[0], creds[1])
-	}
-
-	resp, err := client.Do(req)
+func extensions(ctx *cli.Context, client *httpcl.Client, cmd string, argv *argT) error {
+	_ = cmd
+	url := fmt.Sprintf("%s://%s/status?key=extensions", argv.Protocol, address6(argv))
+	resp, err := client.Get(url)
 	if err != nil {
 		return err
 	}
@@ -634,7 +603,8 @@ func extensions(ctx *cli.Context, cmd string, argv *argT) error {
 // cliJSON fetches JSON from a URL, and displays it at the CLI. If line contains more
 // than one word, then the JSON is filtered to only show the key specified in the
 // second word.
-func cliJSON(ctx *cli.Context, cmd, line, url string, argv *argT) error {
+func cliJSON(ctx *cli.Context, client *httpcl.Client, line, url string) error {
+	_ = ctx
 	// Recursive JSON printer.
 	var pprint func(indent int, m map[string]interface{})
 	pprint = func(indent int, m map[string]interface{}) {
@@ -659,24 +629,7 @@ func cliJSON(ctx *cli.Context, cmd, line, url string, argv *argT) error {
 		}
 	}
 
-	client := http.Client{Transport: &http.Transport{
-		TLSClientConfig: &tls.Config{InsecureSkipVerify: argv.Insecure},
-		Proxy:           http.ProxyFromEnvironment,
-	}}
-
-	req, err := http.NewRequest("GET", url, nil)
-	if err != nil {
-		return err
-	}
-	if argv.Credentials != "" {
-		creds := strings.Split(argv.Credentials, ":")
-		if len(creds) != 2 {
-			return fmt.Errorf("invalid Basic Auth credentials format")
-		}
-		req.SetBasicAuth(creds[0], creds[1])
-	}
-
-	resp, err := client.Do(req)
+	resp, err := client.Get(url)
 	if err != nil {
 		return err
 	}
