@@ -6,10 +6,11 @@ import (
 	"fmt"
 	"net/http"
 	"net/url"
-	"strings"
+
+	httpcl "github.com/rqlite/rqlite/v8/cmd/rqlite/http"
 )
 
-func removeNode(client *http.Client, id string, argv *argT, timer bool) error {
+func removeNode(client *httpcl.Client, id string, argv *argT) error {
 	u := url.URL{
 		Scheme: argv.Protocol,
 		Host:   address6(argv),
@@ -26,19 +27,7 @@ func removeNode(client *http.Client, id string, argv *argT, timer bool) error {
 
 	nRedirect := 0
 	for {
-		req, err := http.NewRequest("DELETE", urlStr, bytes.NewReader(b))
-		if err != nil {
-			return err
-		}
-		if argv.Credentials != "" {
-			creds := strings.Split(argv.Credentials, ":")
-			if len(creds) != 2 {
-				return fmt.Errorf("invalid Basic Auth credentials format")
-			}
-			req.SetBasicAuth(creds[0], creds[1])
-		}
-
-		resp, err := client.Do(req)
+		resp, err := client.Delete(urlStr, bytes.NewReader(b))
 		if err != nil {
 			return err
 		}
