@@ -49,6 +49,9 @@ const (
 	numBackupStepErrors       = "backup_step_errors"
 	numBackupStepDones        = "backup_step_dones"
 	numBackupSleeps           = "backup_sleeps"
+	numPreupdates             = "preupdates"
+	numPreupdatesErrors       = "preupdates_errors"
+	numPreupdatesCBErrors     = "preupdates_callback_errors"
 )
 
 var (
@@ -113,6 +116,9 @@ func ResetStats() {
 	stats.Add(numBackupStepErrors, 0)
 	stats.Add(numBackupStepDones, 0)
 	stats.Add(numBackupSleeps, 0)
+	stats.Add(numPreupdates, 0)
+	stats.Add(numPreupdatesErrors, 0)
+	stats.Add(numPreupdatesCBErrors, 0)
 }
 
 // DB is the SQL database.
@@ -239,6 +245,94 @@ func OpenWithDriver(drv *Driver, dbPath string, fkEnabled, wal bool) (retDB *DB,
 	}, nil
 }
 
+// PreUpdateHookCallback is a callback function that is called before a row is modified
+// in the database.
+type PreUpdateHookCallback func(ev *command.CDCEvent) error
+
+// RegisterPreUpdateHook registers a callback that is called before a row is modified
+// in the database. If a callback is already registered, it is replaced. If hook is nil,
+// the callback is removed.
+func (db *DB) RegisterPreUpdateHook(hook PreUpdateHookCallback, rowIDsOnly bool) error {
+	// Convert from SQLite hook data to rqlite hook data.
+	convertFn := func(d sqlite3.SQLitePreUpdateData) (*command.CDCEvent, error) {
+		ev := &command.CDCEvent{
+			Table:    d.TableName,
+			OldRowId: d.OldRowID,
+			NewRowId: d.NewRowID,
+		}
+
+		switch d.Op {
+		case sqlite3.SQLITE_INSERT:
+			ev.Op = command.CDCEvent_INSERT
+		case sqlite3.SQLITE_UPDATE:
+			ev.Op = command.CDCEvent_UPDATE
+		case sqlite3.SQLITE_DELETE:
+			ev.Op = command.CDCEvent_DELETE
+		default:
+			return ev, fmt.Errorf("unknown preupdate hook operation %d", d.Op)
+		}
+
+		if !rowIDsOnly {
+			c := d.Count()
+			if d.Op != sqlite3.SQLITE_INSERT {
+				oldRow := make([]any, c)
+				err := d.Old(oldRow...)
+				if err != nil && ev.Error == "" {
+					return ev, fmt.Errorf("failed to get old row data: %w", err)
+				}
+				ev.OldRow, err = normalizeCDCValues(oldRow)
+				if err != nil && ev.Error == "" {
+					return ev, fmt.Errorf("failed to normalize old row data: %w", err)
+				}
+			}
+
+			if d.Op != sqlite3.SQLITE_DELETE {
+				newRow := make([]any, c)
+				err := d.New(newRow...)
+				if err != nil && ev.Error == "" {
+					return ev, fmt.Errorf("failed to get new row data: %w", err)
+				}
+				ev.NewRow, err = normalizeCDCValues(newRow)
+				if err != nil && ev.Error == "" {
+					return ev, fmt.Errorf("failed to normalize new row data: %w", err)
+				}
+			}
+		}
+		return ev, nil
+	}
+
+	// Register the callback with the SQLite connection.
+	var cb func(d sqlite3.SQLitePreUpdateData)
+	if hook != nil {
+		cb = func(d sqlite3.SQLitePreUpdateData) {
+			stats.Add(numPreupdates, 1)
+			ev, err := convertFn(d)
+			if err != nil {
+				stats.Add(numPreupdatesErrors, 1)
+				ev.Error = err.Error()
+			}
+			if err := hook(ev); err != nil {
+				stats.Add(numPreupdatesCBErrors, 1)
+			}
+		}
+	}
+	f := func(driverConn interface{}) error {
+		conn := driverConn.(*sqlite3.SQLiteConn)
+		conn.RegisterPreUpdateHook(cb)
+		return nil
+	}
+
+	conn, err := db.rwDB.Conn(context.Background())
+	if err != nil {
+		return err
+	}
+	defer conn.Close()
+	if err := conn.Raw(f); err != nil {
+		return err
+	}
+	return nil
+}
+
 // LastModified returns the last modified time of the database file, or the WAL file,
 // whichever is most recent.
 func (db *DB) LastModified() (time.Time, error) {
@@ -961,7 +1055,7 @@ func (db *DB) queryStmtWithConn(ctx context.Context, stmt *command.Statement, xT
 		if err := rs.Scan(ptrs...); err != nil {
 			return nil, err
 		}
-		params, err := normalizeRowValues(dest, xTypes)
+		params, err := normalizeRowParameters(dest, xTypes)
 		if err != nil {
 			return nil, err
 		}
@@ -1473,11 +1567,11 @@ func populateEmptyTypes(types []string, params []*command.Parameter) error {
 	return nil
 }
 
-// normalizeRowValues performs some normalization of values in the returned rows.
+// normalizeRowParameters performs some normalization of values in the returned rows.
 // Text values come over (from sqlite-go) as []byte instead of strings
 // for some reason, so we have explicitly converted (but only when type
 // is "text" so we don't affect BLOB types)
-func normalizeRowValues(row []interface{}, types []string) ([]*command.Parameter, error) {
+func normalizeRowParameters(row []interface{}, types []string) ([]*command.Parameter, error) {
 	values := make([]*command.Parameter, len(types))
 	for i, v := range row {
 		switch val := v.(type) {
@@ -1544,6 +1638,74 @@ func normalizeRowValues(row []interface{}, types []string) ([]*command.Parameter
 	return values, nil
 }
 
+func normalizeCDCValues(row []any) (*command.CDCRow, error) {
+	cdcRow := &command.CDCRow{
+		Values: make([]*command.CDCValue, len(row)),
+	}
+	for i, v := range row {
+		switch val := v.(type) {
+		case int:
+			cdcRow.Values[i] = &command.CDCValue{
+				Value: &command.CDCValue_I{
+					I: int64(val)},
+			}
+		case int64:
+			cdcRow.Values[i] = &command.CDCValue{
+				Value: &command.CDCValue_I{
+					I: val,
+				},
+			}
+		case float64:
+			cdcRow.Values[i] = &command.CDCValue{
+				Value: &command.CDCValue_D{
+					D: val,
+				},
+			}
+		case bool:
+			cdcRow.Values[i] = &command.CDCValue{
+				Value: &command.CDCValue_B{
+					B: val,
+				},
+			}
+		case string:
+			cdcRow.Values[i] = &command.CDCValue{
+				Value: &command.CDCValue_S{
+					S: val,
+				},
+			}
+		case []byte:
+			if true {
+				cdcRow.Values[i] = &command.CDCValue{
+					Value: &command.CDCValue_S{
+						S: string(val),
+					},
+				}
+			} else {
+				cdcRow.Values[i] = &command.CDCValue{
+					Value: &command.CDCValue_Y{
+						Y: val,
+					},
+				}
+			}
+		case time.Time:
+			rfc3339, err := val.MarshalText()
+			if err != nil {
+				return nil, err
+			}
+			cdcRow.Values[i] = &command.CDCValue{
+				Value: &command.CDCValue_S{
+					S: string(rfc3339),
+				},
+			}
+		case nil:
+			continue
+		default:
+			return nil, fmt.Errorf("unhandled column type: %T %v", val, val)
+		}
+	}
+	return cdcRow, nil
+}
+
 // isTextType returns whether the given type has a SQLite text affinity.
 // http://www.sqlite.org/datatype3.html
 func isTextType(t string) bool {
